%***************************
% Written by Farinaz Edalat
% May 9, 2005
%***************************

%**************************************************************************
% Description: This file 
% (1) downloads the variances and delays of the channel
% model's power-delay-profile(PDP) that is used by the channel simulator to
% generate the channel impulse response
% (2) downloads the channel simulator's generated (complex-valued) impulse response taps
% (3) downloads the channel estimator's estimated phase and magnitude and
% compares that with the channel's frequency response
%**************************************************************************

Ts = 1/(256e6) ; % simulation sampling time (from test.par)

% (1) PDP values
load -ascii model_a_vars.dat
load -ascii delay_Ts_a.dat
variances = model_a_vars;
delays = delay_Ts_a;

figure(1)
stem(delays, variances)  
grid on;
xlabel('Time delay/Ts [sec]')
ylabel('Average relative power')
title('Power Delay Profile')

% (2) Generated impulse-response tap values a=a_i+j*a_q
load -ascii a_i.dat
load -ascii a_q.dat
a = a_i + j*a_q
n = [0:length(a)-1];

figure(2)
stem(n, abs(a))             
grid on;
xlabel('Time delay/Ts [sec]')
title('Channel Impulse Response Magnitude')

% (3) Compute channel's frequency response (from the impulse response)
% and compare with channel estimations
N = 2^15;
n = [1:N];
k = [0:N-1];
omega_dt = 2*pi*k/N;  
omega_ct = omega_dt ./ Ts;
freq = omega_ct ./ (2*pi);
freq_cen = freq - 1/(2*Ts);  % translate to baseband
A = fftshift(fft(a,N));

load -ascii ch_estimator_h_mag.dat; 
load -ascii ch_estimator_h_phase.dat;
H_mag = ch_estimator_h_mag;
H_phase = ch_estimator_h_phase;

figure(3)
H_mags = [H_mag(5:8); H_mag(1:4)];
f = [-4:3].*1e6;
plot( f./1e6, 20*log10(H_mags), 'r*-', freq_cen./1e6, 20*log10(abs(A)))
grid on
xlabel('frequency offset from carrier frequency (MHz)');
title('Channel Frequency Response Magnitude Squared |H|^2 (dB)')
axis([-5 4 -23 1.5])